##  What Is a Workspace?
A SAP LeanIX workspace is the logical group of fact sheets, users, and viewers. Usually, a company uses exactly one workspace for its EAM activities. But there are use cases, in which more than one workspace is used. For example, for different organizational units or subsidiaries, it can make sense to have multiple parallel workspaces.
